From 58f0017d201b87a4ee7db7d118379c7c7e71a7e0 Mon Sep 17 00:00:00 2001
From: McCabe Maxsted
Date: Fri, 4 Dec 2009 12:57:57 -0700
Subject: Added Imprudence VC80 .config files to the repo

---
 ChangeLog.txt                                   |  9 +++++++++
 linden/indra/cmake/CopyWinLibs.cmake            |  8 ++++----
 linden/indra/newview/Imprudence.exe.config      | 20 ++++++++++++++++++++
 linden/indra/newview/ImprudenceDebug.exe.config | 20 ++++++++++++++++++++
 4 files changed, 53 insertions(+), 4 deletions(-)
 create mode 100644 linden/indra/newview/Imprudence.exe.config
 create mode 100644 linden/indra/newview/ImprudenceDebug.exe.config

diff --git a/ChangeLog.txt b/ChangeLog.txt
index 97e3cbc..6b64ccc 100644
--- a/ChangeLog.txt
+++ b/ChangeLog.txt
@@ -1,3 +1,12 @@
+2009-12-04 McCabe Maxsted  <hakushakukun@gmail.com>
+
+	* Added Imprudence VC80 .config files to the repo. 
+	
+	  new file:   linden/indra/newview/Imprudence.exe.config
+	  new file:   linden/indra/newview/ImprudenceDebug.exe.config
+	  modified:   linden/indra/cmake/CopyWinLibs.cmake
+	  
+
 2009-12-02 McCabe Maxsted  <hakushakukun@gmail.com>
 
 	* Forgot to remove the debug entry for libpng12-0.dll from CopyWinLibs.cmake.
diff --git a/linden/indra/newview/Imprudence.exe.config b/linden/indra/newview/Imprudence.exe.config
new file mode 100644
index 0000000..293a9ba
--- /dev/null
+++ b/linden/indra/newview/Imprudence.exe.config
@@ -0,0 +1,20 @@
+<configuration>
+
+       <windows>
+
+              <assemblyBinding xmlns="urn:schemas-microsoft-com:asm.v1">
+
+      <dependentAssembly>
+
+        <assemblyIdentity type="win32" name="Microsoft.VC80.CRT" processorArchitecture="x86" publicKeyToken="1fc8b3b9a1e18e3b"></assemblyIdentity>
+
+        <bindingRedirect oldVersion="8.0.41204.256-" newVersion="0.0.0.0"/>
+
+      </dependentAssembly>
+
+    </assemblyBinding>
+
+       </windows>
+
+</configuration>
+
diff --git a/linden/indra/newview/ImprudenceDebug.exe.config b/linden/indra/newview/ImprudenceDebug.exe.config
new file mode 100644
index 0000000..04d0e00
--- /dev/null
+++ b/linden/indra/newview/ImprudenceDebug.exe.config
@@ -0,0 +1,20 @@
+<configuration>
+
+       <windows>
+
+              <assemblyBinding xmlns="urn:schemas-microsoft-com:asm.v1">
+
+      <dependentAssembly>
+
+        <assemblyIdentity type="win32" name="Microsoft.VC80.DebugCRT" processorArchitecture="x86" publicKeyToken="1fc8b3b9a1e18e3b"></assemblyIdentity>
+
+        <bindingRedirect oldVersion="8.0.41204.256-" newVersion="0.0.0.0"/>
+
+      </dependentAssembly>
+
+    </assemblyBinding>
+
+       </windows>
+
+</configuration>
+
diff --git a/linden/indra/cmake/CopyWinLibs.cmake b/linden/indra/cmake/CopyWinLibs.cmake
index 808c693..add94dd 100644
--- a/linden/indra/cmake/CopyWinLibs.cmake
+++ b/linden/indra/cmake/CopyWinLibs.cmake
@@ -1,7 +1,7 @@
 # -*- cmake -*-
 
 # The copy_win_libs folder contains file lists and a script used to 
 # copy dlls, exes and such needed to run the SecondLife from within 
 # VisualStudio. 
 
 include(CMakeCopyIfDifferent)
@@ -196,7 +196,7 @@ if (MSVC80)
             ARGS
               ${CMAKE_CURRENT_SOURCE_DIR}/build_win32_appConfig.py
               ${CMAKE_CURRENT_BINARY_DIR}/Debug/Microsoft.VC80.DebugCRT.manifest
-              ${CMAKE_CURRENT_SOURCE_DIR}/SecondLifeDebug.exe.config
+              ${CMAKE_CURRENT_SOURCE_DIR}/ImprudenceDebug.exe.config
               ${debug_appconfig_file}
             DEPENDS ${CMAKE_CURRENT_BINARY_DIR}/Debug/Microsoft.VC80.DebugCRT.manifest
             COMMENT "Creating debug app config file"
@@ -241,7 +241,7 @@ if (MSVC80)
             ARGS
               ${CMAKE_CURRENT_SOURCE_DIR}/build_win32_appConfig.py
               ${CMAKE_CURRENT_BINARY_DIR}/Release/Microsoft.VC80.CRT.manifest
-              ${CMAKE_CURRENT_SOURCE_DIR}/SecondLife.exe.config
+              ${CMAKE_CURRENT_SOURCE_DIR}/Imprudence.exe.config
               ${release_appconfig_file}
             DEPENDS ${CMAKE_CURRENT_BINARY_DIR}/Release/Microsoft.VC80.CRT.manifest
             COMMENT "Creating release app config file"
@@ -254,7 +254,7 @@ if (MSVC80)
             ARGS
               ${CMAKE_CURRENT_SOURCE_DIR}/build_win32_appConfig.py
               ${CMAKE_CURRENT_BINARY_DIR}/RelWithDebInfo/Microsoft.VC80.CRT.manifest
-              ${CMAKE_CURRENT_SOURCE_DIR}/SecondLife.exe.config
+              ${CMAKE_CURRENT_SOURCE_DIR}/Imprudence.exe.config
               ${relwithdebinfo_appconfig_file}
             DEPENDS ${CMAKE_CURRENT_BINARY_DIR}/RelWithDebInfo/Microsoft.VC80.CRT.manifest
             COMMENT "Creating relwithdebinfo app config file"
@@ -1,7 +1,7 @@
 
 # The copy_win_libs folder contains file lists and a script used to 
-# copy dlls, exes and such needed to run the SecondLife from within 
+# copy dlls, exes and such needed to run Imprudence from within 
 # VisualStudio. 
 
-- 
cgit v1.1